-- Federal Tables
-- The PDF version is released before the HTML version
-- https://www.irs.gov/forms-pubs/about-publication-15-t
-- https://www.irs.gov/forms-pubs/about-publication-15

-- pymtax must exist, cannot drop and insert because of G/L info
update pymtax set percent=6.2, maximum = 168600
      where taxauthority = 'FE' and taxcode = 'FICA';
update pymtax set percent=6.2, maximum = 168600
      where taxauthority = 'FE' and taxcode = 'FIC2';
update pymtax set percent = 1.45 
      where taxauthority = 'FE' and taxcode = 'MEDI';
update pymtax set percent = 1.45 
      where taxauthority = 'FE' and taxcode = 'MED2';

-- Need to add an employee additional Medicare tax code with a rate of
-- 0.9% and modify tax maint to include a field using pymtax.minwage
-- and pyechk.4gl to calculate on a minimum wage and w2 to include this tax.

-- FUTA (Federal unemployment) has a 5.4% credit if state unemployment tax
-- is paid on time and in full and on the same wages as FUTA. 
-- Federal law provides for a reduction in the FUTA tax credit when a state
-- has outstanding federal loans. The reduction is 0.3% for the first year,
-- and an additional 0.3% each succeeding year until the loan is repaid. 
-- List of states that have a FUTA Credit Reduction State:
-- http://www.irs.gov/Businesses/Small-Businesses-&-Self-Employed/FUTA-Credit-Reduction
update pymtax set percent = .6, maximum = 7000
where taxauthority = 'FE' and taxcode = 'FUTA';


-- https://www.irs.gov/forms-pubs/about-publication-15-t
-- Publication 15T, Annual Percentage Method Tables for Automated Payroll
-- Use the Standard Withholding Rate Schedules, for tax status M, S, H use
-- Form W-4, Step 2, Checkbox, Withholding Rate Schedules for status 1, 2, 3.
-- Column 'base' is amount to withhold.
-- Column 'over' is amount annual wage exceeds.
-- As of 2020 there is no longer a personal exemption amount
delete from pyttax where taxauthority = 'FE';
insert into pyttax (taxauthority, taxcode, taxstatus, statusdescription, 
                    allowance,
                    base1, percent1,  over1,
                    base2, percent2,  over2,
                    base3, percent3,  over3,
                    base4, percent4,  over4,
                    base5, percent5,  over5,
                    base6, percent6,  over6,
                    base7, percent7,  over7) values
                    ('FE', 'FWH', 'M', 'Married', 0,
--           amount withhold (C)     exceeds (E)
                            0.00,  10,     16300,
                         2320.00,  12,     39500,
                        10852.00,  22,    110600,
                        34337.00,  24,    217350,
                        78221.00,  32,    400200,
                       111357.00,  35,    503750,
                       196669.50,  37,    747500
                    );
insert into pyttax (taxauthority, taxcode, taxstatus, statusdescription,
                    allowance,
                    base1, percent1,  over1,
                    base2, percent2,  over2,
                    base3, percent3,  over3,
                    base4, percent4,  over4,
                    base5, percent5,  over5,
                    base6, percent6,  over6,
                    base7, percent7,  over7) values
                    ('FE', 'FWH', 'S', 'Single', 0,
                            0.00,  10,      6000,
                         1160.00,  12,     17600,
                         5426.00,  22,     53150,
                        17168.50,  24,    106525,
                        39110.50,  32,    197950,
                        55678.50,  35,    249725,
                       183647.25,  37,    615350
                    );
insert into pyttax (taxauthority, taxcode, taxstatus, statusdescription,
                    allowance,
                    base1, percent1,  over1,
                    base2, percent2,  over2,
                    base3, percent3,  over3,
                    base4, percent4,  over4,
                    base5, percent5,  over5,
                    base6, percent6,  over6,
                    base7, percent7,  over7) values
                    ('FE', 'FWH', 'H', 'Head of Household', 0,
                            0.00,  10,     13300,
                         1655.00,  12,     29850,
                         7241.00,  22,     76400,
                        15469.00,  24,    113800,
                        37417.00,  32,    205250,
                        53977.00,  35,    257000,
                       181954.50,  37,    622650
                    );
insert into pyttax (taxauthority, taxcode, taxstatus, statusdescription, 
                    allowance,
                    base1, percent1,  over1,
                    base2, percent2,  over2,
                    base3, percent3,  over3,
                    base4, percent4,  over4,
                    base5, percent5,  over5,
                    base6, percent6,  over6,
                    base7, percent7,  over7) values
                    ('FE', 'FWH', '1', 'Married W-4 Checkbox', 0,
                            0.00,  10,     14600,
                         1160.00,  12,     26200,
                         5426.00,  22,     61750,
                        17168.50,  24,    115125,
                        39110.50,  32,    206550,
                        55678.50,  35,    258325,
                        98334.75,  37,    380200
                    );
insert into pyttax (taxauthority, taxcode, taxstatus, statusdescription,
                    allowance,
                    base1, percent1,  over1,
                    base2, percent2,  over2,
                    base3, percent3,  over3,
                    base4, percent4,  over4,
                    base5, percent5,  over5,
                    base6, percent6,  over6,
                    base7, percent7,  over7) values
                    ('FE', 'FWH', '2', 'Single W-4 Checkbox', 0,
                            0.00,  10,      7300,
                          580.00,  12,     13100,
                         2713.00,  22,     30875,
                         8584.25,  24,     57563,
                        19555.25,  32,    103275,
                        27839.25,  35,    129163,
                        91823.63,  37,    311975
                    );
insert into pyttax (taxauthority, taxcode, taxstatus, statusdescription,
                    allowance,
                    base1, percent1,  over1,
                    base2, percent2,  over2,
                    base3, percent3,  over3,
                    base4, percent4,  over4,
                    base5, percent5,  over5,
                    base6, percent6,  over6,
                    base7, percent7,  over7) values
                    ('FE', 'FWH', '3', 'Head House W-4 Check', 0,
                            0.00,  10,     10950,
                          827.50,  12,     19225,
                         3620.50,  22,     42500,
                         7734.50,  24,     61200,
                        18708.50,  32,    106925,
                        26988.50,  35,    132800,
                        90977.25,  37,    315625
                    );

